@@ -10,8 +10,7 @@ import os
 import fnmatch
 import numpy as np
 from scipy import interpolate
-from scipy.special import expn
-
+from scipy.special import exp1
 import ChiantiPy.tools.constants as const
 
 
@@ -19,6 +18,16 @@ def between(array,limits):
     """
     Find the indices of `array` corresponding to values in the range given by `limits`
 
+    Parameters
+    ----------
+
+    array:  `list`, `ndarray`
+        contains a list of elements such a wavelengths
+
+    limits:  `list`, `ndarray`
+        a 2 element array specifying the lower and upper limits of the array to be included
+
+
     """
     array = np.asarray(array)
     nlines = len(array)
@@ -213,6 +222,32 @@ def zion2localFilename(z,ion, dielectronic=False):
         fname = os.path.join(dir,thisel,thisone,thisone)
     return fname
 
+def zion2experimental(z, ion, dielectronic=False):
+    """
+    Convert atomic number and ion number to spectroscopic notation string
+
+    Parameters
+    ----------
+
+    z : `int`
+        The atomic number/nuclear charge
+    ion : `int`
+        the ionization stage, 0 for neutrals, 1 for singly ionized
+    dielectronic : `bool`, optional
+
+    Returns
+    -------
+    expt : `str`
+        the experimental/laboratory notation for the ion, such as Fe 13+
+    """
+    if (z-1 < len(const.El)) and (ion <= z+1):
+        expt = const.El[z-1].capitalize()+' ' + '%i'%(ion-1) + '+'
+        if dielectronic:
+            expt += ' d'
+    else:  expt = ''
+    return expt
+
+
 
 def zion2spectroscopic(z,ion, dielectronic=False):
     """
@@ -270,7 +305,8 @@ def convertName(name):
     iso = Z - stage + 1
     isoEl = const.El[iso - 1].capitalize()
     spectro = zion2spectroscopic(Z, stage)
-    return {'Z':Z,'Ion':stage,'Dielectronic':dielectronic, 'Element':els.capitalize(), 'higher':higher, 'lower':lower, 'filename':filename, 'iso':iso, 'isoEl':isoEl, 'spectroscopic':spectro}
+    expt = zion2experimental(Z,  stage)
+    return {'Z':Z,'Ion':stage,'Dielectronic':dielectronic, 'Element':els.capitalize(), 'higher':higher, 'lower':lower, 'filename':filename, 'iso':iso, 'isoEl':isoEl, 'spectroscopic':spectro, 'experimental':expt}
 
 
 def ion2filename(ions):
@@ -288,6 +324,11 @@ def ion2filename(ions):
     fname:  str
         the full file name of the ion directory in the CHIANTI database
         assumes a top directory from the environmental variable XUVTOP
+
+    Todo
+    ----
+
+    this duplicates what 'convertName' does
     """
     dir = os.environ["XUVTOP"]
     nameDict = convertName(ions)
@@ -389,19 +430,19 @@ def splomDescale(splom, energy):
     #
     #
     nenergy = energy.size
-    nsplom = len(splom['deryd'])
+    nsplom = len(splom['de'])
     # for these files, there are 5 spline points
-    nspl = 5
+    nspl = [splom['splom'].shape[0]]*splom['splom'].shape[1]
     if nenergy > 1:
         omega = np.zeros((nsplom,nenergy),np.float64)
     else:
         omega = np.zeros(nsplom,np.float64)
     #
-    dx = 1./(float(nspl)-1.)
-    sxint = dx*np.arange(nspl)  # IDL sx
-    for isplom in range(0,nsplom):
+    for isplom in range(nsplom):
         #
-        sx1 = energy/(splom['deryd'][isplom]*const.ryd2Ev)  # IDL x_int
+        dx = 1./(float(nspl[isplom])-1.)
+        sxint = dx*np.arange(nspl[isplom])  # IDL sx
+        sx1 = energy/(splom['de'][isplom]*const.ryd2Ev)  # IDL x_int
         good = sx1 >= 1.
         # make sure there are some valid energies above the threshold
         if good.sum():
@@ -628,10 +669,10 @@ def descale_bt(bte,btomega,f,ev1):
     ----------
     .. [3] Burgess, A. and Tully, J. A., 1992, A&A, `254, 436 <http://adsabs.harvard.edu/abs/1992A%26A...254..436B>`_
     """
-    u = 1.-f+np.exp(np.log(f)/(1.-bte))
+    u = 1.- f + np.exp(np.log(f)/(1.-bte))
     energy = u*ev1
-    omega = (np.log(u)-1.+np.exp(1.))*btomega
-    return [energy,omega]
+    omega = (np.log(u) -1. + np.exp(1.))*btomega
+    return [energy, omega]
 
 
 def descale_bti(bte,btx,f,ev1):
@@ -702,9 +743,29 @@ def scale_bt(evin,omega,f,ev1):
     btomega = omega/(np.log(u)-1.+np.exp(1.))
     return [bte,btomega]
 
-def scale_bt_rate(inDict, ip, f=1.7):
+def descale_bti_rate(btTemperature, btRate, ip,  f=2.0):
     """
-    Apply ionization descaling of [7]_, a Burgess-Tully type scaling to ionization rates and
+    Apply ionization descaling of [7]_, a Burgess-Tully type scaling to bt scaled ionization rates and
+    temperatures.  The result is to return a temperature array and a ionization rate array.
+
+    Parameters
+    ----------
+    btTemperature :  `array-like`
+        the bt scaled temperature
+    btRate : `array-like`
+        the bt scaled ionization rate
+    ip :  `float`
+        the ionization potential in eV.
+    f :  `float` (optional)
+        the scaling parameter, 1.7 generally works well
+    """
+    temperature = (ip/const.boltzmannEv)*(np.exp(np.log(f/(1.-btTemperature))) - f)
+    rate = (1./np.sqrt(btTemperature))*ip**(-1.5)*exp1(1./btTemperature)*btRate
+    return {'temperature':temperature, 'rate':rate}
+
+def scale_bt_rate(inDict, ip, f=2.0):
+    """
+    Apply ionization scaling of [7]_, a Burgess-Tully type scaling to ionization rates and
     temperatures. The result of the scaling is to return a scaled temperature between 0 and 1 and a
     slowly varying scaled rate as a function of scaled temperature. In addition, the scaled rates
     vary slowly along an iso-electronic sequence.
@@ -726,7 +787,7 @@ def scale_bt_rate(inDict, ip, f=1.7):
     if ('temperature' and 'rate') in inDict.keys():
         rT = inDict['temperature']*const.boltzmannEv/ip
         btTemperature = 1. - np.log(f)/np.log(rT + f)
-        btRate = np.sqrt(rT)*inDict['rate']*ip**1.5/(expn(1,1./rT))
+        btRate = np.sqrt(rT)*inDict['rate']*ip**1.5/(exp1(1./rT))
         inDict['btTemperature'] = btTemperature
         inDict['btRate'] = btRate
         inDict['ip'] = ip
